<?php
/**
 * The featured layouts
 *
 * @package Agency
 */

defined( 'WPINC' ) || exit;

/**
 * Class for featured layouts.
 */
class Agency_Featured_Layouts extends Agency_Base {

	/**
	 * Current layout.
	 *
	 * @var string
	 */
	public $current = null;

	/**
	 * Hold sections.
	 *
	 * @var array
	 */
	private $sections = null;

	/**
	 * The Construct
	 */
	public function __construct() {
		$this->sections = agency_get_settings( 'featured_categories' );
	}

	/**
	 * Render layout
	 */
	public function render() {

		if ( empty( $this->sections ) ) {
			$this->current = array(
				'layout'         => 'default',
				'posts_layout'   => 'layout-default',
				'excerpt_length' => 20,
				'unique_id'      => 'nothing',
				'is_latest'      => true,
			);

			get_template_part( 'template-parts/posts', 'default' );
			return;
		}

		$has_latest_posts = $this->has_latest_posts_section( $this->sections );

		foreach ( $this->sections as $section ) :

			$posts_layout = $section['blog_layout'];

			$layout = $posts_layout;
			if ( 'layout-default' === $posts_layout ) {
				$layout = 'default';
			}

			$category = $section['mts_featured_category'];

			if ( is_paged() ) {

				if ( $has_latest_posts && 'latest' !== $category ) {
					continue;
				}

				if ( 'layout-html' === $layout ) {
					continue;
				}

				$this->current = array(
					'layout'         => $layout,
					'posts_layout'   => $posts_layout,
					'category'       => $category,
					'excerpt_length' => 20,
					'unique_id'      => $section['unique_id'],
					'is_latest'      => false,
				);
				get_template_part( 'template-parts/posts', $layout );
				return;
			}

			$section = wp_parse_args( array_filter( $section ), array(
				'blog_layout'                      => '',
				'mts_featured_category_postsnum'   => 3,
				'mts_featured_category_excerpt'    => 20,
				'mts_featured_category_background' => '',
				'mts_featured_category_margin'     => '',
				'mts_featured_category_padding'    => '',
				'unique_id'                        => '',
			) );

			if ( 'latest' !== $category ) {
				$this->category_posts( $category, $section['mts_featured_category_postsnum'] );
			}

			$this->current = array(
				'layout'         => $layout,
				'category'       => $category,
				'unique_id'      => $section['unique_id'],
				'is_latest'      => 'latest' !== $category,
				'posts_layout'   => $posts_layout,
				'posts_count'    => $section['mts_featured_category_postsnum'],
				'excerpt_length' => $section['mts_featured_category_excerpt'],
			);
			if ( have_posts() ) {
				get_template_part( 'template-parts/posts', $layout );
			}

		endforeach;
	}

	/**
	 * Check if array of sections contains a Latest Posts section.
	 *
	 * @param array $sections Sections.
	 * @return boolean
	 */
	public function has_latest_posts_section( $sections ) {
		foreach ( $sections as $section ) {
			if ( 'latest' === $section['mts_featured_category'] ) {
				return true;
			}
		}
		return false;
	}

	/**
	 * Genrate post_container classes
	 */
	public function get_post_container_class() {
		$classes   = array();
		$classes[] = 'layout-' . $this->current['unique_id'];
		$classes[] = $this->current['layout'] . '-container';
		$classes[] = 'clearfix';

		echo join( ' ', $classes );
	}

	/**
	 * Set category in main query
	 *
	 * @param  int $category    Category ID.
	 * @param  int $posts_count Number of posts.
	 */
	public function category_posts( $category, $posts_count ) {
		global $wp_query;

		$wp_query = new WP_Query( 'ignore_sticky_posts=1&category_name=' . $category . '&posts_per_page=' . $posts_count );
	}

	/**
	 * Get section title.
	 *
	 * @param int $category Category id or name.
	 */
	public function get_section_title( $category = false ) {
		if ( agency_get_settings( 'featured_category_title_' . $this->current['unique_id'] ) ) :
			$category = ! $category ? $this->current['category'] : $category;
		?>
		<div class="title-container title-id-<?php echo $this->current['unique_id']; ?>">
			<?php
			if ( ! $this->current['is_latest'] && 'latest' === $category ) {
				echo '<h3 class="featured-category-title">';
				_e( 'Latest', 'agency' );
				echo '</h3></div>';
				return;
			}
			$category_name = agency_get_cat_name( $category );
			$category_id   = get_cat_ID( $category_name );
			?>
			<h3 class="featured-category-title"><a href="<?php echo esc_url( get_category_link( $category_id ) ); ?>" title="<?php echo esc_attr( $category_name ); ?>"><?php echo esc_html( $category_name ); ?></a></h3>
		</div>
		<?php
		endif;
	}

	/**
	 * Get post title
	 */
	public function get_post_title() {
		?>
		<header>

			<h2 class="title front-view-title">
				<a href="<?php echo esc_url( get_the_permalink() ); ?>" title="<?php the_title_attribute(); ?>"><?php echo the_title(); ?></a>
			</h2>

		</header>
		<?php
	}

	/**
	 * Get post thumbnail according to layout
	 *
	 * @param  boolean Display review.
	 * @param  integer $j      Even or Odd.
	 */
	public function get_post_thumbnail( $j = 0 ) {

		$default_thumb = 'agency-featured';
		$thumbs        = array(
			'layout-1' => 'agency-layout-1',
		);

		$size = isset( $thumbs[ $this->current['posts_layout'] ] ) ? $thumbs[ $this->current['posts_layout'] ] : $default_thumb;
		?>
		<a href="<?php echo esc_url( get_the_permalink() ); ?>" title="<?php the_title_attribute(); ?>" id="featured-thumbnail" class="post-image post-image-left <?php echo $size; ?>">
			<div class="featured-thumbnail">
				<?php
				$attr = [
					'title'   => esc_attr( get_the_title() ),
					'alt'     => esc_attr( get_the_title() ),
					'loading' => 'lazy',
				];
				if ( has_post_thumbnail() ) {
					the_post_thumbnail( $size, $attr );
				} else {
					echo '<img src="' . get_template_directory_uri() . '/images/nothumb-' . $size . '.png" alt="' . __( 'No Preview', 'agency' ) . '"  class="wp-post-image" />';
				}
				?>
			</div>
			<?php
			if ( function_exists( 'wp_review_show_total' ) ) {
				wp_review_show_total( true, 'latestPost-review-wrapper' );
			}
			?>
		</a>
		<?php
	}

	/**
	 * Get post content
	 */
	public function get_post_content() {
		?>

		<div class="front-view-content">
			<?php
			if ( empty( agency_excerpt() ) ) {
				echo agency_truncate( get_the_content(), $this->current['excerpt_length'], 'words' );
			} else {
				echo agency_excerpt( $this->current['excerpt_length'] );
			}
			agency_readmore();
			?>
		</div>

		<?php
	}

	/**
	 * Get post meta info
	 */
	public function get_post_meta() {
		agency_the_post_meta( 'home', $this->current['unique_id'] );
	}

	/**
	 * Get sidebar
	 *
	 */
	public function get_sidebar() {

		$cat_name = __( 'Latest ', 'agency' );

		if ( 'latest' !== $this->current['category'] ) {
			$cat_name = ucwords( agency_get_cat_name( $this->current['category'] ) );
		}
		if ( 'default' == $this->current['layout'] ) {
			$this->current['layout'] = 'layout-default';
		}
		?>
		<aside id="sidebar" class="sidebar c-4-12 post-<?php echo $this->current['layout']; ?>" role="complementary" itemscope itemtype="http://schema.org/WPSideBar">
			<?php
			dynamic_sidebar( sanitize_title( strtolower( 'post-' . $this->current['layout'] . $cat_name ) ) );
			?>
		</aside>
		<?php
	}

	/**
	 * Get post pagination
	 */
	public function get_post_pagination() {
		if ( ! $this->current['is_latest'] ) {
			agency_pagination( agency_get_settings( 'mts_pagenavigation_type' ) );
		}
		wp_reset_query();
	}
}
